"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.babelCreator = void 0;
const creator_utils_1 = require("@knapsack/creator-utils");
const file_utils_1 = require("@knapsack/file-utils");
const path_1 = require("path");
const { pkg } = (0, file_utils_1.findUpPkgJson)(__dirname);
exports.babelCreator = (0, creator_utils_1.createCreator)({
    id: 'babel-config-starter',
    title: 'Babel Config Starter',
    description: pkg.description,
    getQuestions: async () => ({
        moduleType: {
            type: 'choice',
            choices: [
                { title: 'ES Modules', value: 'es' },
                { title: 'CommonJS', value: 'cjs' },
            ],
        },
        filename: {
            type: 'choice',
            choices: [{ value: 'babel.config.json' }, { value: '.babelrc' }],
        },
        addScripts: {
            type: 'boolean',
            title: 'Update package.json with build script?',
            default: false,
        },
        addDep: {
            type: 'boolean',
            title: 'Update package.json with devDependency?',
            default: true,
        },
    }),
    async getTasks({ answers, config: { dest } }) {
        const { addScripts, addDep, filename, moduleType } = answers;
        const isEs = moduleType === 'es';
        const to = (path) => (0, path_1.join)(dest, path);
        const { pkgPath } = (0, file_utils_1.findUpPkgJson)(dest);
        return [
            {
                title: `Creating ${filename}`,
                task: async () => creator_utils_1.tasks.addFile({
                    destination: to(filename),
                    handlePriorFile: 'overwrite',
                    contents: {
                        extends: `@knapsack/babel-config-starter${isEs ? '/es' : ''}`,
                    },
                }),
            },
            {
                title: 'Added script to package.json',
                task: async () => {
                    if (!addScripts)
                        return 'Did not add script to package.json';
                    await creator_utils_1.tasks.updatePkgJson({
                        dir: pkgPath,
                        pkg: {
                            scripts: {
                                build: 'babel --extensions .js,.ts --copy-files --out-dir dist/ src/',
                                start: 'npm run build -- watch',
                            },
                        },
                    });
                    return 'Did add script to package.json';
                },
            },
            {
                title: 'Added deps to package.json',
                skip: !addDep,
                task: async () => {
                    if (!addDep)
                        return 'Did not add devDependency to package.json';
                    await creator_utils_1.tasks.updatePkgJson({
                        dir: pkgPath,
                        pkg: {
                            devDependencies: {
                                [pkg.name]: `^${pkg.version}`,
                            },
                        },
                    });
                    return 'Did add devDependency to package.json';
                },
            },
        ];
    },
});
//# sourceMappingURL=babel-config-creator.js.map