// import { ConfigFunction, CreateConfigItemOptions, } from '@babel/core';

const useESModules = true;

export function getPresetEnv<
  Opt extends {
    modules: false | 'commonjs';
    targets?:
      | {
          esmodules: true;
        }
      | Record<'chrome' | 'firefox', string>;
  },
>(options: Opt): [string, Opt] {
  return [require.resolve('@babel/preset-env'), options];
}

export const presetEnvEs = getPresetEnv({
  modules: false,
  targets: {
    esmodules: true,
  },
});

export const presetEnvCjs = getPresetEnv({
  modules: 'commonjs',
});

export const baseConfig = {
  presets: [
    [
      require.resolve('@babel/preset-react'),
      {
        development: process.env.NODE_ENV !== 'production',
      },
    ],
    [
      require.resolve('@babel/preset-typescript'),
      {
        isTSX: true,
        allExtensions: true,
        jsxPragma: 'React',
      },
    ],
  ],
  plugins: [
    // https://www.npmjs.com/package/babel-plugin-transform-async-to-promises
    // !isNode && require.resolve('babel-plugin-transform-async-to-promises'),
    require.resolve('@babel/plugin-syntax-dynamic-import'),
    require.resolve('@babel/plugin-proposal-object-rest-spread'),
    require.resolve('@babel/plugin-proposal-nullish-coalescing-operator'),
    [
      require.resolve('@babel/plugin-proposal-decorators'),
      {
        decoratorsBeforeExport: true,
      },
    ],
    require.resolve('@babel/plugin-proposal-class-properties'),
    require.resolve('@babel/plugin-proposal-optional-chaining'),
  ].filter(Boolean),
};

export const esBabelConfig = {
  ...baseConfig,
  presets: [...baseConfig.presets, presetEnvEs],
};

export const cjsBabelConfig = {
  ...baseConfig,
  presets: [...baseConfig.presets, presetEnvCjs],
};
